CharImage

Struct CharImage 

pub struct CharImage { /* private fields */ }
A pre-filled character image for fast text extraction.

Built at init time by cycling through a character set to fill a buffer. At cycle time, a hash-based offset extracts a substring. This is the Rust equivalent of nosqlbench’s CharBufImage.

Implementations

Source

impl CharImage

pub fn new(charset: &str, size: usize) -> Self

Build a character image by repeating charset to fill size chars.

pub fn hashed(charset: &str, size: usize, seed: u64) -> Self

Build a character image by hashing into the charset.