pub fn header(format: EmitFormat, names: &[&str]) -> Option<String>Expand description
The header line for a format, if the format has one.
pub fn header(format: EmitFormat, names: &[&str]) -> Option<String>The header line for a format, if the format has one.