EmitRow

Struct EmitRow 

pub struct EmitRow {
    pub format: String,
    pub names: String,
    /* private fields */
}
Append one formatted row to the calling thread’s buffer and return the number of values emitted. format is map, csv, or jsonl; names is the comma-separated list of wire names in the same order as the variadic values.

Fields

format: String

The format argument, as given at construction.

names: String

The names argument, as given at construction.

Implementations

Source

impl EmitRow

pub fn new(format: String, names: String, n_wires: usize) -> Self

A emit_row node with the given constant arguments.